==> haskell-fsnotify-0.2.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.2.1.1
id: fsnotify-0.2.1.1-DDsropDW7bB10WticE3Xxt
key: fsnotify-0.2.1.1-DDsropDW7bB10WticE3Xxt
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
author: Mark Dittmer <mark.s.dittmer@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
abi: 765719c8bcf20c859e2c430ecf104e99
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fsnotify-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/fsnotify-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/fsnotify-0.2.1.1
hs-libraries: HSfsnotify-0.2.1.1-DDsropDW7bB10WticE3Xxt
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    hinotify-0.3.9-JlGkv9dYANlFh8TRWOAzjE
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             hinotify-0.3.9-JlGkv9dYANlFh8TRWOAzjE=6dd7304a3b08e06b74bbacb4e667a9d4
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.2.1.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fsnotify
version: 0.2.1.1
id: fsnotify-0.2.1.1-I7K4if6wM4qFJ1D5dNxZZa
key: fsnotify-0.2.1.1-I7K4if6wM4qFJ1D5dNxZZa
license: BSD3
maintainer: Greg Weber <greg@gregweber.info>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/haskell-fswatch/hfsnotify
synopsis: Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.
category: Filesystem
author: Mark Dittmer <mark.s.dittmer@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.FSNotify System.FSNotify.Devel
hidden-modules: System.FSNotify.Listener System.FSNotify.Path
                System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux
abi: 4b51b8f38397150f3791b0e2b688870a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fsnotify-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/fsnotify-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/fsnotify-0.2.1.1
hs-libraries: HSfsnotify-0.2.1.1-I7K4if6wM4qFJ1D5dNxZZa
depends:
    base-4.10.1.0 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz time-1.8.0.2
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    hinotify-0.3.9-JlGkv9dYANlFh8TRWOAzjE
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             hinotify-0.3.9-JlGkv9dYANlFh8TRWOAzjE=6dd7304a3b08e06b74bbacb4e667a9d4
haddock-interfaces: /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html: /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
